import _extends from "@babel/runtime/helpers/esm/extends";
import _get from "lodash/get";
import * as React from 'react';
import { setDisplayName, wrapDisplayName } from 'recompose';
import defaultLocale from './locales/default';
import IntlContext from './IntlContext';

var mergeObject = function mergeObject(list) {
  return list.reduce(function (a, b) {
    a = _extends({}, a, {}, b);
    return a;
  }, {});
};

function withLocale(combineKeys) {
  if (combineKeys === void 0) {
    combineKeys = [];
  }

  return function (BaseComponent) {
    var factory = React.createFactory(BaseComponent);
    var WithLocale = React.forwardRef(function (props, ref) {
      return React.createElement(IntlContext.Consumer, null, function (value) {
        var locale = mergeObject(combineKeys.map(function (key) {
          return _get(value || defaultLocale, "" + key);
        }));

        if (value && typeof value.rtl !== undefined) {
          locale.rtl = value.rtl;
        } else if (typeof window !== 'undefined' && (document.body.getAttribute('dir') || document.dir) === 'rtl') {
          locale.rtl = true;
        }

        return factory(_extends({
          ref: ref,
          locale: locale
        }, props));
      });
    });
    WithLocale.displayName = BaseComponent.displayName;

    if (process.env.NODE_ENV !== 'production') {
      return setDisplayName(wrapDisplayName(BaseComponent, 'withLocale'))(WithLocale);
    }

    return WithLocale;
  };
}

export default withLocale;